@@ -7,11 +7,11 @@
 *** css stylesheets
 
 ** Author: Ralph Amissah
-  <ralph@amissah.com>
-  <ralph.amissah@gmail.com>
+  [ralph@amissah.com]
+  [ralph.amissah@gmail.com]
 
 ** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
+  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
   All Rights Reserved.
 
 ** License: GPL 3 or later:
@@ -31,14 +31,12 @@
   more details.
 
   You should have received a copy of the GNU General Public License along with
-  this program. If not, see <http://www.gnu.org/licenses/>.
+  this program. If not, see [http://www.gnu.org/licenses/].
 
   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
-  <http://www.fsf.org/licensing/licenses/gpl.html>
-  <http://www.gnu.org/licenses/gpl.html>
-
-  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+  [http://www.fsf.org/licensing/licenses/gpl.html]
+  [http://www.gnu.org/licenses/gpl.html]
 
 ** SiSU uses:
   * Standard SiSU markup syntax,
@@ -46,12 +44,12 @@
   * Standard SiSU object citation numbering and system
 
 ** Hompages:
-  <http://www.jus.uio.no/sisu>
-  <http://www.sisudoc.org>
+  [http://www.jus.uio.no/sisu]
+  [http://www.sisudoc.org]
 
 ** Git
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/css.rb;hb=HEAD>
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/css.rb;hb=HEAD]
 
 =end
 module SiSU_Style
@@ -1311,6 +1309,7 @@ WOK
   h1.center, h2.center, h3.center, h4.center, h5.center, h6.center, h7.center {
     text-align: center;
   }
+  h0 { font-size: 125%; }
   h1 { font-size: 120%; }
   h2 { font-size: 115%; }
   h3 { font-size: 110%; }
@@ -1318,7 +1317,6 @@ WOK
   h5 { font-size: 100%; }
   h6 { font-size: 100%; }
   h7 { font-size: 100%; }
-  h0 { font-size: 80%; }
 
   h1.i {margin-left: 2em;}
   h2.i {margin-left: 3em;}
