@@ -871,13 +871,13 @@ module SiSU_Commandline
         else { bool: true, set: :na }
         end
         act[:minitoc]=if select_arr.inspect \
-        =~/"--inc-minitoc"/
+        =~/"--minitoc"|"--inc-minitoc"/
           { bool: true, set: :on }
         elsif select_arr.inspect \
         =~/"--(?:exc|no)-minitoc"/ \
         || act[:switch][:off].inspect =~/"minitoc"/
           { bool: false, set: :off }
-        else { bool: true, set: :na }
+        else { bool: false, set: :na }
         end
         act[:links_to_manifest]=if select_arr.inspect \
         =~/"--inc-links-to-manifest"|"--inc-manifest-links"/
@@ -902,10 +902,10 @@ module SiSU_Commandline
         =~/"--(?:exc|no)-manifest-minitoc"|"--(?:exc|no)-minitoc"/ \
         || act[:switch][:off].inspect =~/"manifest_minitoc"|"minitoc"/
           { bool: false, set: :off }
-        else { bool: true, set: :na }
+        else { bool: false, set: :na }
         end
         act[:metadata]=if select_arr.inspect \
-        =~/"--inc-metadata"/
+        =~/"--metadata"|"--inc-metadata"/
           { bool: true, set: :on }
         elsif select_arr.inspect \
         =~/"--(?:exc|no)-metadata"/ \
@@ -920,7 +920,7 @@ module SiSU_Commandline
         =~/"--(?:exc|no)-html-minitoc"|"--(?:exc|no)-minitoc"/ \
         || act[:switch][:off].inspect =~/"html_minitoc"|"minitoc"/
           { bool: false, set: :off }
-        else { bool: true, set: :na }
+        else { bool: false, set: :na }
         end
         act[:html_navigation]=if select_arr.inspect \
         =~/"--inc-html-navigation"|"--inc-navigation"/
